[Bf-blender-cvs] [63b9d7c3651] temp-geometry-nodes-instances-api-v2: Rename function

Hans Goudey noreply at git.blender.org
Sat Feb 6 16:21:16 CET 2021


Commit: 63b9d7c3651e3a0413e3fdef871a169661a6dd66
Author: Hans Goudey
Date:   Fri Feb 5 18:52:34 2021 -0600
Branches: temp-geometry-nodes-instances-api-v2
https://developer.blender.org/rB63b9d7c3651e3a0413e3fdef871a169661a6dd66

Rename function

===================================================================

M	source/blender/blenkernel/BKE_geometry_set.hh
M	source/blender/blenkernel/intern/geometry_set.cc

===================================================================

diff --git a/source/blender/blenkernel/BKE_geometry_set.hh b/source/blender/blenkernel/BKE_geometry_set.hh
index 771664ef209..ffc632d55f9 100644
--- a/source/blender/blenkernel/BKE_geometry_set.hh
+++ b/source/blender/blenkernel/BKE_geometry_set.hh
@@ -480,8 +480,8 @@ class VolumeComponent : public GeometryComponent {
 using ForeachGeometryCallbackConst = std::function<void(
     const GeometryComponent &component, blender::Span<blender::float4x4> transforms)>;
 
-void BKE_foreach_geometry_component_recursive(const GeometrySet &geometry_set,
-                                              const ForeachGeometryCallbackConst &callback);
+void BKE_geometry_set_foreach_component_recursive(const GeometrySet &geometry_set,
+                                                  const ForeachGeometryCallbackConst &callback);
 
 /**
  * Used to keep track of a group of instances using the same geometry data.
diff --git a/source/blender/blenkernel/intern/geometry_set.cc b/source/blender/blenkernel/intern/geometry_set.cc
index 351bfa3c6dc..2423740b32b 100644
--- a/source/blender/blenkernel/intern/geometry_set.cc
+++ b/source/blender/blenkernel/intern/geometry_set.cc
@@ -681,8 +681,8 @@ static void foreach_geometry_component_recursive(const GeometrySet &geometry_set
  * \note For convenience (to avoid duplication in the caller),
  * this also executes the callback for the argument geometry set.
  */
-void BKE_foreach_geometry_component_recursive(const GeometrySet &geometry_set,
-                                              const ForeachGeometryCallbackConst &callback)
+void BKE_geometry_set_foreach_component_recursive(const GeometrySet &geometry_set,
+                                                  const ForeachGeometryCallbackConst &callback)
 {
   float4x4 unit_transform;
   unit_m4(unit_transform.values);
@@ -754,8 +754,8 @@ static void collect_geometry_set_recursive(const GeometrySet &geometry_set,
 
 /**
  * Return a vector of geometry sets, including a flattened array of instances. This approach
  * (as opposed to #BKE_foreach_geometry_component_recursive) can be used where multiple iterations
  * over the input data are needed, or where it simplifies code enough.
  *
  * \note For convenience (to avoid duplication in the caller),
  * the returned vector also contains the argument geometry set.
@@ -754,8 +754,8 @@ static void collect_geometry_set_recursive(const GeometrySet &geometry_set,
 /**
  * Return a vector of geometry sets, including a flattened array of instances. This approach
- * (as opposed to #BKE_foreach_geometry_component_recursive) can be used where multiple iterations
- * over the input data are needed, or where it simplifies code enough.
+ * (as opposed to #BKE_geometry_set_foreach_component_recursive) can be used where multiple
+ * iterations over the input data are needed, or where it simplifies code enough.
  *
  * \note For convenience (to avoid duplication in the caller),



More information about the Bf-blender-cvs mailing list